@@ -3,6 +3,14 @@ import time
 import requests
 
 
+class APIResponseException(Exception):
+    def __init__(self, message):
+        self.message = message
+
+    def __str__(self):
+        return self.message
+
+
 def setSession(scraper):
     scraper.session = requests.Session()
 
@@ -60,6 +68,31 @@ def select(scraper, worksheetName, selection):
     return r.json()
 
 
+def filter(scraper, worksheetName, globalFieldName, selection):
+    delayExecution(scraper)
+    payload = (
+        (
+            "visualIdPresModel", (None, json.dumps({
+                "worksheet": worksheetName,
+                "dashboard": scraper.dashboard
+            }))
+        ),
+        ("globalFieldName", (None, globalFieldName)),
+        ("membershipTarget", (None, "filter")),
+        ("filterIndices", (None, json.dumps(selection))),
+        ("filterUpdateType", (None, "filter-replace"))
+    )
+    r = scraper.session.post(
+        f'{scraper.host}{scraper.tableauData["vizql_root"]}/sessions/{scraper.tableauData["sessionid"]}/commands/tabdoc/categorical-filter-by-index',
+        files=payload,
+        verify=scraper.verify
+    )
+    try:
+        return r.json()
+    except ValueError:
+        raise APIResponseException(message=r.text)
+
+
 def setParameterValue(scraper, parameterName, value):
     delayExecution(scraper)
     payload = (
@@ -75,6 +108,19 @@ def setParameterValue(scraper, parameterName, value):
     return r.json()
 
 
+def goToSheet(scraper, windowId):
+    delayExecution(scraper)
+    payload = (
+        ("windowId", (None, windowId)),
+    )
+    r = scraper.session.post(
+        f'{scraper.host}{scraper.tableauData["vizql_root"]}/sessions/{scraper.tableauData["sessionid"]}/commands/tabdoc/goto-sheet',
+        files=payload,
+        verify=scraper.verify
+    )
+    return r.json()
+
+
 def delayExecution(scraper):
     if scraper.lastActionTime != 0:
         currentTime = time.time()
